@@ -281,7 +281,7 @@ def should_support_postgresql_import_functionality
   end
 
   describe "with binary field" do
-    let(:binary_value) { "\xE0'c\xB2\xB0\xB3Bh\\\xC2M\xB1m\\I\xC4r".force_encoding('ASCII-8BIT') }
+    let(:binary_value) { "\xE0'c\xB2\xB0\xB3Bh\\\xC2M\xB1m\\I\xC4r".dup.force_encoding('ASCII-8BIT') }
     it "imports the correct values for binary fields" do
       alarms = [Alarm.new(device_id: 1, alarm_type: 1, status: 1, secret_key: binary_value)]
       assert_difference "Alarm.count", +1 do
@@ -290,6 +290,30 @@ def should_support_postgresql_import_functionality
       assert_equal(binary_value, Alarm.first.secret_key)
     end
   end
+
+  unless ENV["SKIP_COMPOSITE_PK"]
+    describe "with composite foreign keys" do
+      let(:account_id) { 555 }
+      let(:customer) { Customer.new(account_id: account_id, name: "foo") }
+      let(:order) { Order.new(account_id: account_id, amount: 100, customer: customer) }
+
+      it "imports and correctly maps foreign keys" do
+        assert_difference "Customer.count", +1 do
+          Customer.import [customer]
+        end
+
+        assert_difference "Order.count", +1 do
+          Order.import [order]
+        end
+
+        db_customer = Customer.last
+        db_order = Order.last
+
+        assert_equal db_customer.orders.last, db_order
+        assert_not_equal db_order.customer_id, nil
+      end
+    end
+  end
 end
 
 def should_support_postgresql_upsert_functionality
