@@ -51,14 +51,22 @@ ActiveRecord::Base.logger = Logger.new("log/test.log")
 ActiveRecord::Base.logger.level = Logger::DEBUG
 
 if ENV['AR_VERSION'].to_f >= 6.0
-  yaml_config = YAML.load_file(test_dir.join("database.yml"))[adapter]
+  yaml_config = if Gem::Version.new(Psych::VERSION) >= Gem::Version.new('3.2.1')
+    YAML.safe_load_file(test_dir.join("database.yml"), aliases: true)[adapter]
+  else
+    YAML.load_file(test_dir.join("database.yml"))[adapter]
+  end
   config = ActiveRecord::DatabaseConfigurations::HashConfig.new("test", adapter, yaml_config)
   ActiveRecord::Base.configurations.configurations << config
 else
   ActiveRecord::Base.configurations["test"] = YAML.load_file(test_dir.join("database.yml"))[adapter]
 end
 
-ActiveRecord::Base.default_timezone = :utc
+if ActiveRecord.respond_to?(:default_timezone)
+  ActiveRecord.default_timezone = :utc
+else
+  ActiveRecord::Base.default_timezone = :utc
+end
 
 require "activerecord-import"
 ActiveRecord::Base.establish_connection :test
